@@ -1,19 +1,25 @@
 module Database.Persist.Class
-    (
+    ( ToBackendKey (..)
+
     -- * PersistStore
-      PersistStore (..)
+    , PersistStore (..)
     , getJust
     , belongsTo
     , belongsToJust
+    , insertEntity
 
     -- * PersistUnique
     , PersistUnique (..)
     , getByValue
     , insertBy
     , replaceUnique
+    , checkUnique
+    , onlyUnique
 
     -- * PersistQuery
     , PersistQuery (..)
+    , selectSource
+    , selectKeys
     , selectList
     , selectKeysList
 
@@ -28,6 +34,10 @@ module Database.Persist.Class
     -- * PersistConfig
     , PersistConfig (..)
 
+    -- * Lifting
+    , HasPersistBackend (..)
+    , liftPersist
+
     -- * JSON utilities
     , keyValueEntityToJSON, keyValueEntityFromJSON
     , entityIdToJSON, entityIdFromJSON
